Documentation
¶
Index ¶
Constants ¶
const (
// DefaultBuildUser represents the default builduser
DefaultBuildUser = "cimalva"
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Baton ¶
type Baton struct {
// BuildUser represents the name of the build user
BuildUser string
// ProjectID represents the unique projectID of this project
ProjectID string
// ProjectName represents the name of the project under discussion
ProjectName string
// CommitID represents the latest commitID / commit hash of the checkout
CommitID string
// ProjectRoot represents the root of the current project
ProjectRoot string
// ProjectRootParent representsthe parent of project root directory
ProjectRootParent string
}
Baton represents the information exchanged / shared between pipelines
func (*Baton) CopyFilesToDockerImage ¶ added in v0.2.1
func (myBaton *Baton) CopyFilesToDockerImage() ciutil.OnWriterFunc
CopyFilesToDockerImage copies the files from dockerdirectory to image
func (*Baton) GetDockerImageTag ¶ added in v0.2.1
GetDockerImageTag returns the image tag for the given information
Click to show internal directories.
Click to hide internal directories.